@@ -1890,8 +1890,8 @@ muse_cplarray_exp(cpl_array *aArray)
 /**
    @brief Linear interpolation of a 1d array
    @param aTargetAbscissa Target abscissa (x) array
-   @param aSourceAbscissa Target abscissa (x) array
-   @param aSourceOrdinate Target ordinate (y) array
+   @param aSourceAbscissa Source abscissa (x) array
+   @param aSourceOrdinate Source ordinate (y) array
    @@return Target ordinate (y) array
 
    @cpl_ensure_code{aTargetAbscissa, CPL_ERROR_NULL_INPUT}
@@ -1908,7 +1908,6 @@ muse_cplarray_exp(cpl_array *aArray)
    (i.e. extrapolation is not allowed).
 
    The source table must be of at least length 2.
-
 */
 /*----------------------------------------------------------------------------*/
 cpl_array *
