@@ -75,10 +75,15 @@
 #define MUSE_TAG_ASTROMETRY_REFERENCE "ASTROMETRY_REFERENCE"
 #define MUSE_TAG_ASTROMETRY_WCS       "ASTROMETRY_WCS"
 #define MUSE_TAG_CUBE_ASTROMETRY      "DATACUBE_ASTROMETRY"
+#define MUSE_TAG_ACAL_MASK      "AUTOCAL_MASK"
+#define MUSE_TAG_ACAL_FACTORS   "AUTOCAL_FACTORS"
+#define MUSE_TAG_RAMAN_IMAGES   "RAMAN_IMAGES"
 #define MUSE_TAG_SKY_SPECTRUM   "SKY_SPECTRUM"
+#define MUSE_TAG_SKY_IMAGE      "SKY_IMAGE"
 #define MUSE_TAG_SKY_MASK       "SKY_MASK"
 #define MUSE_TAG_SKY_CONT       "SKY_CONTINUUM"
 #define MUSE_TAG_SKY_LINES      "SKY_LINES"
+#define MUSE_TAG_RAMAN_LINES    "RAMAN_LINES"
 #define MUSE_TAG_FILTER_LIST    "FILTER_LIST"
 #define MUSE_TAG_OUTPUT_WCS     "OUTPUT_WCS"
 #define MUSE_TAG_IMAGE_FOV        "IMAGE_FOV"
@@ -239,7 +244,8 @@
 #define QC_WAVECAL_PREFIX                  "ESO QC WAVECAL"
 #define QC_WAVECAL_PREFIXi                 QC_WAVECAL_PREFIX" INPUT%u"
 #define QC_WAVECAL_PREFIXli                QC_WAVECAL_PREFIX" LAMP%u INPUT%u"
-#define QC_WAVECAL_SLICEj_PREFIX           QC_WAVECAL_PREFIX" SLICE%hu"
+#define QC_WAVECAL_SLICE_PREFIX            QC_WAVECAL_PREFIX" SLICE"
+#define QC_WAVECAL_SLICEj_PREFIX           QC_WAVECAL_SLICE_PREFIX"%hu"
 #define QC_WAVECAL_SLICEj_LINES_NDET       QC_WAVECAL_SLICEj_PREFIX" LINES NDET"
 #define QC_WAVECAL_SLICEj_LINES_NID        QC_WAVECAL_SLICEj_PREFIX" LINES NID"
 #define QC_WAVECAL_SLICEj_LINES_PEAK_MEAN  QC_WAVECAL_SLICEj_PREFIX" LINES PEAK MEAN"
@@ -304,6 +310,14 @@
 #define QC_POST_PREFIX_EXPCOMBINE "ESO QC EXPCOMB"
 #define QC_POST_PREFIX_STANDARD   "ESO QC STANDARD"
 #define QC_POST_PREFIX_ASTROMETRY "ESO QC ASTRO"
+/* the Raman removal keywords, only in scipost */
+#define QC_POST_RAMAN_SP_XX       QC_POST_PREFIX_SCIPOST" RAMAN SPATIAL XX"
+#define QC_POST_RAMAN_SP_XY       QC_POST_PREFIX_SCIPOST" RAMAN SPATIAL XY"
+#define QC_POST_RAMAN_SP_YY       QC_POST_PREFIX_SCIPOST" RAMAN SPATIAL YY"
+#define QC_POST_RAMAN_SP_X        QC_POST_PREFIX_SCIPOST" RAMAN SPATIAL X"
+#define QC_POST_RAMAN_SP_Y        QC_POST_PREFIX_SCIPOST" RAMAN SPATIAL Y"
+#define QC_POST_RAMAN_FLUXO2      QC_POST_PREFIX_SCIPOST" RAMAN FLUX O2"
+#define QC_POST_RAMAN_FLUXN2      QC_POST_PREFIX_SCIPOST" RAMAN FLUX N2"
 /* end of the FWHMi.X and FWHMi.Y keywords, depending on recipe */
 #define QC_POST_NDET              "%s NDET"
 #define QC_POST_LAMBDA            "%s LAMBDA"
@@ -316,6 +330,10 @@
 #define QC_POST_FWHM_MAD          "%s FWHM MAD"
 
 /* Exposure alignment QC headers */
+#define QC_ALIGN_BKG_MEDIAN       "ESO QC EXPALIGN BKG MEDIAN"
+#define QC_ALIGN_BKG_MAD          "ESO QC EXPALIGN BKG MAD"
+#define QC_ALIGN_THRESHOLD        "ESO QC EXPALIGN THRESHOLD"
+#define QC_ALIGN_NDET             "ESO QC EXPALIGN NDET"
 #define QC_ALIGN_NDETi            "ESO QC EXPALIGN NDET%d"
 #define QC_ALIGN_NMATCHi          "ESO QC EXPALIGN NMATCH%d"
 #define QC_ALIGN_NMATCH_MIN       "ESO QC EXPALIGN NMATCH MIN"
