@@ -852,6 +852,7 @@ muse_lsf_fold_rectangle(cpl_image *aLsfImage, const muse_wcs *aWCS,
   return CPL_ERROR_NONE;
 } /* muse_lsf_fold_rectangle() */
 
+
 /*----------------------------------------------------------------------------*/
 /**
    @brief Apply the LSF to a number of data points of one slice
@@ -937,4 +938,64 @@ muse_lsf_apply(const cpl_image *aLsfImage, const muse_wcs *aWCS,
   return CPL_ERROR_NONE;
 }
 
+
+/*----------------------------------------------------------------------------*/
+/**
+   @brief  Add line spread function to a MUSE slice of a pixtable
+   @param  aPixtable   table containing one slice, with wavelength and
+                       an lsf column
+   @param  aWavelength line wave length
+   @param  aFlux       line flux
+   @param  aLsfImage   image containing the line spread function for the slice
+   @param  aLsfWCS     WCS definition for aLsfImage
+
+   This will add the LSF for one line to the pixtable. The pixtable is
+   required to hold an "lsf" column with values set to
+   zero. Subsequent calls of this function add the line spread
+   functions of each call.
+*/
+/*----------------------------------------------------------------------------*/
+cpl_error_code
+muse_lsf_apply_slice(muse_pixtable *aPixtable, double aWavelength,
+                     double aFlux,
+                     cpl_image *aLsfImage, muse_wcs *aLsfWCS)
+{
+  cpl_propertylist *order = cpl_propertylist_new();
+  cpl_propertylist_append_bool(order, MUSE_PIXTABLE_LAMBDA, CPL_FALSE);
+  cpl_table_sort(aPixtable->table, order);
+  cpl_propertylist_delete(order);
+
+  cpl_array *lsf_data = muse_cpltable_extract_column(aPixtable->table, "lsf");
+
+  cpl_array *lambda = NULL;
+  if (cpl_table_get_column_type(aPixtable->table, MUSE_PIXTABLE_LAMBDA)
+      == CPL_TYPE_DOUBLE) {
+    lambda = muse_cpltable_extract_column(aPixtable->table,
+                                          MUSE_PIXTABLE_LAMBDA);
+  } else {
+    cpl_table_cast_column(aPixtable->table, MUSE_PIXTABLE_LAMBDA,
+                          "lambda_double", CPL_TYPE_DOUBLE);
+    lambda = muse_cpltable_extract_column(aPixtable->table, "lambda_double");
+  }
+
+  double l_min = aLsfWCS->crval1 + aLsfWCS->cd11 * (1 - aLsfWCS->crpix1),
+    l_max = aLsfWCS->crval1
+    + aLsfWCS->cd11 * (cpl_image_get_size_x(aLsfImage) - aLsfWCS->crpix1);
+  cpl_size imin = muse_cplarray_find_sorted(lambda, aWavelength + l_min);
+  cpl_size imax = muse_cplarray_find_sorted(lambda, aWavelength + l_max);
+  cpl_array *l0 = cpl_array_extract(lambda, imin, imax-imin+1);
+  cpl_array_subtract_scalar(l0, aWavelength);
+  muse_lsf_apply(aLsfImage, aLsfWCS, l0, aWavelength);
+  cpl_array_multiply_scalar(l0, aFlux);
+  muse_cplarray_add_window(lsf_data, imin, l0);
+  cpl_array_delete(l0);
+  cpl_array_unwrap(lsf_data);
+  cpl_array_unwrap(lambda);
+  if (cpl_table_has_column(aPixtable->table, "lambda_double")) {
+    cpl_table_erase_column(aPixtable->table, "lambda_double");
+  }
+
+  return CPL_ERROR_NONE;
+}
+
 /**@}*/
