@@ -1100,7 +1100,8 @@ muse_trace(const muse_image *aImage, int aNSum, double aEdgeFrac, int aFitorder,
           jhi = j + aNSum - 1;
 #if 0
       cpl_msg_debug(__func__, "slice=%d, center=%f, cut region: %d,%d,%d,%d",
-                    (int)islice + 1, cpl_vector_get(centers, islice), ilo, ihi, jlo, jhi);
+                    (int)islice + 1, cpl_vector_get(centers, islice),
+                    ilo, ihi, jlo, jhi);
 #endif
       cpl_image *tmp = cpl_image_collapse_window_create(image->data,
                                                         ilo, jlo, ihi, jhi,
@@ -1115,6 +1116,11 @@ muse_trace(const muse_image *aImage, int aNSum, double aEdgeFrac, int aFitorder,
       double midpoint = muse_trace_edgefinder(cut, aEdgeFrac, &left, &right,
                                               &highSN, ifu);
       cpl_vector_delete(cut);
+#if 0 /* same output as above, but with the high S/N classification added */
+      cpl_msg_debug(__func__, "slice=%d, center=%f, cut region: %d,%d,%d,%d, "
+                    "%s S/N", (int)islice + 1, cpl_vector_get(centers, islice),
+                    ilo, ihi, jlo, jhi, highSN ? "high" : "low");
+#endif
       /* keep left edge of the standard edge detection, in      *
        * case we are dealing with the slices 37 to 48 in IFU 24 */
       double left1 = left + noffset;
@@ -1201,10 +1207,10 @@ muse_trace(const muse_image *aImage, int aNSum, double aEdgeFrac, int aFitorder,
     cpl_vector_dump(ytrace, stdout), fflush(stdout);
 #endif
 
-    /* iterate through input points and the fit with XXX 5 sigma rejections */
+    /* iterate through input points and the fit with 5 sigma rejections */
     const float kWSigma = 5, kRSigma = 5;
-    cpl_msg_debug(__func__, "Working on slice %d of IFU %hhu (kWSigma=%f, "
-                  "kRSigma=%f)", (int)islice + 1, ifu, kWSigma, kRSigma);
+    cpl_msg_debug(__func__, "Fitting traces in slice %d of IFU %hhu (kWSigma=%"
+                  ".1f, kRSigma=%.1f)", (int)islice + 1, ifu, kWSigma, kRSigma);
     cpl_vector *mse = cpl_vector_new(MUSE_TRACE_NPOLY);
     cpl_vector_fill(mse, -1.);
     cpl_polynomial **tracefits = muse_trace_iterate_fit(xtrace, ytrace, widths,
