@@ -2,7 +2,7 @@
 /* vim:set sw=2 sts=2 et cin: */
 /*
  * This file is part of the MUSE Instrument Pipeline
- * Copyright (C) 2005-2015 European Southern Observatory
+ * Copyright (C) 2005-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -249,9 +249,9 @@ muse_wcs_centroid_stars(muse_image *aImage, float aSigma,
     fwhmguess = 4.; /* [pix] assume median seeing in WFM */
   } else { /* use nominal MUSE spaxel scale to get FWHM guess [pix] */
     if (muse_pfits_get_mode(image->header) < MUSE_MODE_NFM_AO_N) {
-      fwhmguess /= (kMuseSpaxelSizeX_WFM + kMuseSpaxelSizeX_WFM) / 2;
+      fwhmguess /= (kMuseSpaxelSizeX_WFM + kMuseSpaxelSizeY_WFM) / 2;
     } else {
-      fwhmguess /= (kMuseSpaxelSizeX_NFM + kMuseSpaxelSizeX_NFM) / 2;
+      fwhmguess /= (kMuseSpaxelSizeX_NFM + kMuseSpaxelSizeY_NFM) / 2;
     }
   }
 #endif
@@ -703,7 +703,9 @@ muse_wcs_solve(muse_wcs_object *aWCSObj, cpl_table *aReference,
   }
 
   /* construct a basic input WCS */
-  cpl_propertylist *wcsin = muse_wcs_create_default();
+  cpl_propertylist *wcsin = muse_wcs_create_default(aWCSObj->cube
+                                                    ? aWCSObj->cube->header
+                                                    : NULL);
   cpl_propertylist_append_double(wcsin, "CRVAL1", aWCSObj->ra);
   cpl_propertylist_append_double(wcsin, "CRVAL2", aWCSObj->dec);
   cpl_propertylist_update_double(wcsin, "CRPIX1", aWCSObj->crpix1);
@@ -1162,17 +1164,32 @@ muse_wcs_optimize_solution(muse_wcs_object *aWCSObj, float aDetSigma,
 /*----------------------------------------------------------------------------*/
 /**
   @brief   Create FITS headers containing a default (relative) WCS.
+  @param   aHeader   optional input header containing instrument mode
+                     (can be NULL)
   @return  A cpl_propertylist * on success, failures are not expected to occur.
 
   Units in the WCS are in deg (as required by the FITS standard, §8.2),
   approximately relative to a MUSE field center. Rotation is not known in this
   function, so assumed to be zero. This needs to be adapted when applying this
   WCS to data.
+
+  If aHeader was not NULL, then that propertylist is queried for the INS.MODE.
+  Depending on the outcome, the scale will be adapted to either WFM (the
+  default, also if aHeader is NULL) or NFM.
  */
 /*----------------------------------------------------------------------------*/
 cpl_propertylist *
-muse_wcs_create_default(void)
+muse_wcs_create_default(const cpl_propertylist *aHeader)
 {
+  /* try getting the instrument mode; if no header is present or    *
+   * it does not contain the INS.MODE keyword, this detaults to WFM */
+  cpl_errorstate state = cpl_errorstate_get();
+  cpl_boolean iswfm = muse_pfits_get_mode(aHeader) <= MUSE_MODE_WFM_AO_N;
+  if (!cpl_errorstate_is_equal(state)) {
+    cpl_errorstate_set(state);
+  } /* if */
+
+  /* create output header */
   cpl_propertylist *wcs = cpl_propertylist_new();
 
   /* We only care about the spatial axes, pretend that we have a 2D image;    *
@@ -1198,13 +1215,21 @@ muse_wcs_create_default(void)
   /* CRPIX is the zero order correction to the astrometry, set zero here */
   cpl_propertylist_append_double(wcs, "CRPIX1", smallvalue);
   /* negative value, to signify that east is to the left */
-  cpl_propertylist_append_double(wcs, "CD1_1", -kMuseSpaxelSizeX_WFM / 3600);
+  if (iswfm) {
+    cpl_propertylist_append_double(wcs, "CD1_1", -kMuseSpaxelSizeX_WFM / 3600.);
+  } else {
+    cpl_propertylist_append_double(wcs, "CD1_1", -kMuseSpaxelSizeX_NFM / 3600.);
+  }
   cpl_propertylist_append_string(wcs, "CTYPE1", "RA---TAN");
   cpl_propertylist_append_string(wcs, "CUNIT1", "deg");
 
   /* axis 2 */
   cpl_propertylist_append_double(wcs, "CRPIX2", smallvalue);
-  cpl_propertylist_append_double(wcs, "CD2_2", kMuseSpaxelSizeY_WFM / 3600);
+  if (iswfm) {
+    cpl_propertylist_append_double(wcs, "CD2_2", kMuseSpaxelSizeY_WFM / 3600.);
+  } else {
+    cpl_propertylist_append_double(wcs, "CD2_2", kMuseSpaxelSizeY_NFM / 3600.);
+  }
   cpl_propertylist_append_string(wcs, "CTYPE2", "DEC--TAN");
   cpl_propertylist_append_string(wcs, "CUNIT2", "deg");
 
@@ -1584,7 +1609,7 @@ muse_wcs_celestial_from_pixel(cpl_propertylist *aHeader, double aX, double aY,
   @return  CPL_ERROR_NONE for success, any other value for failure
 
   The world coordinate system from aHeader is used to do the transformation,
-  only the gnomonic (TAN) is supported.
+  only the gnomonic (TAN) projection is supported.
 
   Uses Eqns (5), (12), (13), and (54) from Calabretta & Greisen 2002 A&A 395,
   1077 (Paper II). We use that phi_p = 180 deg for zenithal projections (like
