@@ -124,7 +124,7 @@ muse_astrometry_compute(muse_processing *aProcessing,
   muse_wcs_object **wcsobjs = cpl_calloc(nexposures, sizeof(muse_wcs_object *));
   int i;
   for (i = 0; i < nexposures; i++) {
-    wcsobjs[i] = muse_postproc_process_exposure(prop, i, NULL);
+    wcsobjs[i] = muse_postproc_process_exposure(prop, i, NULL, NULL, NULL, NULL);
     if (!wcsobjs[i]) {
       int i2;
       for (i2 = 0; i2 <= i; i2++) {
