@@ -140,54 +140,6 @@ muse_create_sky_load_pixtable(muse_processing *aProcessing,
   return pixtable;
 }
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Create a white-light image of the field of view.
-  @param    aPixtable   Pixel table with the exposure.
-  @param    aCRSigma    Sigma level for cocmic ray rejection.
-  @return   A muse_image * on success or NULL on error.
-
-  If aCRSigma is a positive number, detect cosmic rays, flag them in the pixel
-  table, and ignore them in the whitelight image.
- */
-/*----------------------------------------------------------------------------*/
-static muse_image *
-muse_create_sky_whitelight_image(muse_pixtable *aPixtable, double aCRSigma)
-{
-  cpl_boolean usegrid = getenv("MUSE_COLLAPSE_PIXTABLE")
-                      && atoi(getenv("MUSE_COLLAPSE_PIXTABLE")) > 0;
-  muse_resampling_type type = usegrid ? MUSE_RESAMPLE_NONE
-                                      : MUSE_RESAMPLE_WEIGHTED_DRIZZLE;
-  muse_resampling_params *params = muse_resampling_params_new(type);
-  if (aCRSigma > 0.) {
-    params->crtype = MUSE_RESAMPLING_CRSTATS_MEDIAN;
-    params->crsigma = aCRSigma;
-  }
-  muse_pixgrid *grid = NULL;
-  muse_datacube *cube = muse_resampling_cube(aPixtable, params,
-                                             usegrid ? &grid : NULL);
-  if (cube == NULL) {
-    cpl_msg_error(__func__, "Could not create cube for whitelight image");
-    muse_resampling_params_delete(params);
-    muse_pixgrid_delete(grid);
-    return NULL;
-  }
-  muse_image *image = NULL;
-  muse_table *fwhite = muse_table_load_filter(NULL, "white");
-  if (usegrid) {
-    params->method = MUSE_RESAMPLE_WEIGHTED_DRIZZLE;
-    image = muse_resampling_collapse_pixgrid(aPixtable, grid,
-                                             cube, fwhite, params);
-  } else {
-    image = muse_datacube_collapse(cube, fwhite);
-  }
-  muse_resampling_params_delete(params);
-  muse_pixgrid_delete(grid);
-  muse_datacube_delete(cube);
-  muse_table_delete(fwhite);
-  return image;
-} /* muse_create_sky_whitelight_image() */
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Interpret the command line options and execute the data processing
@@ -231,11 +183,11 @@ muse_create_sky_compute(muse_processing *aProcessing,
   muse_mask *smask = muse_processing_load_mask(aProcessing, MUSE_TAG_SKY_MASK);
   if (smask) { /* apply existing mask on input pixel table */
     cpl_table_select_all(pixtable->table);
-    muse_pixtable_and_selected_mask(pixtable, smask);
+    muse_pixtable_and_selected_mask(pixtable, smask, NULL, NULL);
     muse_mask_delete(smask);
   }
 
-  muse_image *whitelight = muse_create_sky_whitelight_image(pixtable, crsigmac);
+  muse_image *whitelight = muse_postproc_whitelight(pixtable, crsigmac);
   if (whitelight == NULL) {
     cpl_msg_error(__func__, "Could not create whitelight image");
     return -1;
@@ -248,7 +200,7 @@ muse_create_sky_compute(muse_processing *aProcessing,
   muse_processing_save_mask(aProcessing, -1, sky_mask, MUSE_TAG_SKY_MASK);
 
   cpl_table_select_all(pixtable->table);
-  muse_pixtable_and_selected_mask(pixtable, sky_mask);
+  muse_pixtable_and_selected_mask(pixtable, sky_mask, NULL, NULL);
   cpl_table_not_selected(pixtable->table);
   cpl_table_erase_selected(pixtable->table);
   muse_image_delete(whitelight);
