@@ -2,7 +2,7 @@
 /* vim:set sw=2 sts=2 et cin: */
 /*
  * This file is part of the MUSE Instrument Pipeline
- * Copyright (C) 2005-2014 European Southern Observatory
+ * Copyright (C) 2005-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,87 +35,6 @@
  *                             Functions code                                *
  *---------------------------------------------------------------------------*/
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Apply spatial offsets and flux scale to a pixel table (of a single
-            exposure)
-  @param    aPT        the pixel table to be adapted
-  @param    aOffsets   the table with offsets and scalings to apply
-  @param    aPurpose   some words about the purpose, just for info-level output
-
-  Their interpretation is copied from muse_xcombine_tables(), but only the first
-  value in these variables is interpreted as offset (in deg) and flux scaling
-  factor.
- */
-/*----------------------------------------------------------------------------*/
-static void
-muse_scipost_offsets_scale(muse_pixtable *aPT, const cpl_table *aOffsets,
-                           const char *aPurpose)
-{
-  if (!aPT || !aOffsets) {
-    return;
-  }
-  if (!aPT->header) {
-    return;
-  }
-  cpl_msg_info(__func__, "Applying offsets to %s...", aPurpose);
-  cpl_msg_indent_more();
-  double ra =  muse_pfits_get_ra(aPT->header),
-         dec = muse_pfits_get_dec(aPT->header),
-         *offsets = muse_xcombine_find_offsets(aOffsets,
-                                               muse_pfits_get_dateobs(aPT->header));
-  char keyword[KEYWORD_LENGTH], comment[KEYWORD_LENGTH];
-  if (offsets) {
-    if (isfinite(offsets[0]) && isfinite(offsets[1])) {
-      ra -= offsets[0];
-      dec -= offsets[1];
-      cpl_msg_debug(__func__, "Applying coordinate offsets to exposure: %e/%e"
-                    " deg", offsets[0], offsets[1]);
-      /* update RA/DEC in the header of the pixel table */
-      cpl_errorstate state = cpl_errorstate_get();
-      cpl_propertylist_update_double(aPT->header, "RA", ra);
-      if (!cpl_errorstate_is_equal(state)) {
-        cpl_errorstate_set(state);
-        cpl_propertylist_update_float(aPT->header, "RA", ra);
-      }
-      cpl_propertylist_set_comment(aPT->header, "RA", "offset applied!");
-      state = cpl_errorstate_get();
-      cpl_propertylist_update_double(aPT->header, "DEC", dec);
-      if (!cpl_errorstate_is_equal(state)) {
-        cpl_errorstate_set(state);
-        cpl_propertylist_update_float(aPT->header, "DEC", dec);
-      }
-      cpl_propertylist_set_comment(aPT->header, "DEC", "offset applied!");
-      /* store in the header of the pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1);
-      snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA_C, offsets[0] * 3600.);
-      cpl_propertylist_append_double(aPT->header, keyword, offsets[0]);
-      cpl_propertylist_set_comment(aPT->header, keyword, comment);
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1);
-      snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC_C, offsets[1] * 3600.);
-      cpl_propertylist_append_double(aPT->header, keyword, offsets[1]);
-      cpl_propertylist_set_comment(aPT->header, keyword, comment);
-    } /* if spatial offsets */
-    if (isnormal(offsets[2])) { /* valid flux scale */
-      /* get and apply the scale */
-      cpl_msg_debug(__func__, "Scaling flux of exposure by %g.", offsets[2]);
-      muse_pixtable_flux_multiply(aPT, offsets[2]);
-      /* store in the header of the pixel table */
-      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1);
-      cpl_propertylist_append_double(aPT->header, keyword, offsets[2]);
-      cpl_propertylist_set_comment(aPT->header, keyword, MUSE_HDR_FLUX_SCALEi_C);
-    } /* if scale */
-    /* store date of changed exposure in the header of the output pixel table */
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1);
-    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1);
-    cpl_propertylist_append_string(aPT->header, keyword,
-                                   muse_pfits_get_dateobs(aPT->header));
-    cpl_propertylist_set_comment(aPT->header, keyword, comment);
-  } /* if offsets */
-  cpl_free(offsets);
-  cpl_msg_indent_less();
-} /* muse_scipost_offsets_scale() */
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Interpret the command line options and execute the data processing
@@ -137,7 +56,8 @@ int
 muse_scipost_compute(muse_processing *aProcessing,
                      muse_scipost_params_t *aParams)
 {
-  const char *savevalid = "cube,skymodel,individual,positioned,combined,stacked";
+  const char *savevalid = "cube,autocal,raman,skymodel,individual,positioned,"
+                          "combined,stacked";
   if (!muse_postproc_check_save_param(aParams->save, savevalid)) {
     return -1;
   }
@@ -161,16 +81,19 @@ muse_scipost_compute(muse_processing *aProcessing,
   prop->extinction = muse_processing_load_ctable(aProcessing,
                                                  MUSE_TAG_EXTINCT_TABLE, 0);
   /* astrometric correction */
+  prop->astrometry = aParams->astrometry;
   if (aParams->astrometry) {
     prop->wcs = muse_processing_load_header(aProcessing, MUSE_TAG_ASTROMETRY_WCS);
-    if (!prop->wcs) {
-      /* if it was not in the input, create a default WFM astrometry */
-      cpl_msg_warning(__func__, "Using default MUSE WFM astrometry, output "
-                      "world coordinates will be inaccurate!");
-      prop->wcs = muse_wcs_create_default();
-    }
   }
-
+  /* self calibration */
+  prop->autocalib = MUSE_POSTPROC_AUTOCALIB_NONE;
+  if (aParams->autocalib == MUSE_SCIPOST_PARAM_AUTOCALIB_DEEPFIELD) {
+    prop->autocalib = MUSE_POSTPROC_AUTOCALIB_DEEPFIELD;
+  }
+  /* Raman emission handling */
+  prop->raman_width = aParams->raman_width;
+  prop->raman_lines = muse_raman_lines_load(aProcessing);
+  /* sky subtraction methods and parameters */
   const struct {
     int par;
     muse_postproc_skymethod postproc;
@@ -211,6 +134,7 @@ muse_scipost_compute(muse_processing *aProcessing,
   }
   cpl_array_delete(crarray);
 
+  /* further setup for sky subtraction */
 #ifdef USE_LSF_PARAMS
   cpl_errorstate prestate = cpl_errorstate_get();
 #endif
@@ -262,6 +186,28 @@ muse_scipost_compute(muse_processing *aProcessing,
     prop->sky_mask = muse_processing_load_mask(aProcessing, MUSE_TAG_SKY_MASK);
   }
 
+  /* warn about bad combinations of inputs regarding Raman correction */
+  if (prop->raman_lines) {
+    cpl_msg_debug(__func__, "Raman 2D correction wanted (%s given)...",
+                  MUSE_TAG_RAMAN_LINES);
+    if (prop->sky_continuum) {
+      cpl_msg_warning(__func__, "Using a %s together with Raman correction (%s)"
+                      " is unlikely to give good results!", MUSE_TAG_SKY_CONT,
+                      MUSE_TAG_RAMAN_LINES);
+    }
+    if (prop->skymodel_params.fraction < 0.5) {
+      cpl_msg_warning(__func__, "Using a small sky fraction (%.2f) together "
+                      "with Raman correction (%s) is unlikely to give good "
+                      "results!", prop->skymodel_params.fraction,
+                      MUSE_TAG_RAMAN_LINES);
+    }
+  }
+
+  /* also load the LSF, if we need it for Raman correction */
+  if (prop->raman_lines && !prop->lsf_cube) {
+    prop->lsf_cube = muse_lsf_cube_load_all(aProcessing);
+  }
+
   /* sort input pixel tables into different exposures */
   prop->exposures = muse_processing_sort_exposures(aProcessing);
   if (!prop->exposures) {
@@ -285,8 +231,13 @@ muse_scipost_compute(muse_processing *aProcessing,
   muse_pixtable **pixtables = cpl_calloc(nexposures + 1, sizeof(muse_pixtable *));
   int i;
   for (i = 0; i < nexposures; i++) {
-    muse_postproc_sky_outputs *skyout = cpl_calloc(1, sizeof(muse_postproc_sky_outputs));
-    pixtables[i] = muse_postproc_process_exposure(prop, i, skyout);
+    muse_postproc_autocal_outputs *autocal
+      = cpl_calloc(1, sizeof(muse_postproc_autocal_outputs));
+    muse_datacube *ramancube = NULL;
+    muse_postproc_sky_outputs *skyout
+      = cpl_calloc(1, sizeof(muse_postproc_sky_outputs));
+    pixtables[i] = muse_postproc_process_exposure(prop, i, autocal, &ramancube,
+                                                  skyout, offsets);
     if (!pixtables[i]) {
       int i2;
       for (i2 = 0; i2 <= i; i2++) {
@@ -295,10 +246,46 @@ muse_scipost_compute(muse_processing *aProcessing,
       cpl_free(pixtables);
       muse_postproc_properties_delete(prop);
       cpl_table_delete(offsets);
+      muse_mask_delete(autocal->mask);
+      muse_table_delete(autocal->table);
+      cpl_free(autocal);
+      muse_datacube_delete(ramancube);
+      muse_image_delete(skyout->image);
+      muse_mask_delete(skyout->mask);
+      cpl_table_delete(skyout->spectrum);
+      cpl_table_delete(skyout->lines);
+      cpl_table_delete(skyout->continuum);
+      cpl_free(skyout);
       return -1; /* enough error messages, just return */
-    }
+    } /* if !pixtable */
+
+    /* save the autocalibration products, if requested */
+    if (strstr(aParams->save, "autocal")) {
+      if (autocal->mask) {
+        muse_processing_save_mask(aProcessing, -1, autocal->mask,
+                                  MUSE_TAG_ACAL_MASK);
+      }
+      if (autocal->table) {
+        muse_processing_save_table(aProcessing, -1, autocal->table, NULL,
+                                   MUSE_TAG_ACAL_FACTORS, MUSE_TABLE_TYPE_MUSE);
+      }
+    } /* if save autocal */
+    muse_mask_delete(autocal->mask);
+    muse_table_delete(autocal->table);
+    cpl_free(autocal);
+
+    /* save the Raman product, if requested */
+    if (strstr(aParams->save, "raman") && ramancube) {
+      muse_processing_save_cube(aProcessing, -1, ramancube,
+                                MUSE_TAG_RAMAN_IMAGES, MUSE_CUBE_TYPE_FITS);
+      muse_datacube_delete(ramancube);
+    } /* if save Raman outputs */
+
     /* save the effectively used sky products, if requested */
     if (strstr(aParams->save, "skymodel")) {
+      if (skyout->image) {
+        muse_processing_save_image(aProcessing, -1, skyout->image, MUSE_TAG_SKY_IMAGE);
+      }
       if (skyout->mask) {
         muse_processing_save_mask(aProcessing, -1, skyout->mask, MUSE_TAG_SKY_MASK);
       }
@@ -323,7 +310,8 @@ muse_scipost_compute(muse_processing *aProcessing,
         muse_sky_save_continuum(aProcessing, skyout->continuum, header);
         cpl_propertylist_delete(header);
       }
-    }
+    } /* if save skymodel */
+    muse_image_delete(skyout->image);
     muse_mask_delete(skyout->mask);
     cpl_table_delete(skyout->spectrum);
     cpl_table_delete(skyout->lines);
@@ -341,8 +329,8 @@ muse_scipost_compute(muse_processing *aProcessing,
       muse_pixtable *pt = muse_pixtable_duplicate(pixtables[i]);
       /* since after positioning it is too late to *
        * adapt the reference position, do it now   */
-      muse_scipost_offsets_scale(pt, offsets,
-                                 "positioned pixel table for saving");
+      muse_postproc_offsets_scale(pt, offsets,
+                                  "positioned pixel table for saving");
       muse_wcs_position_celestial(pt, muse_pfits_get_ra(pt->header),
                                   muse_pfits_get_dec(pt->header));
       muse_processing_save_table(aProcessing, -1, pt, NULL,
@@ -384,8 +372,8 @@ muse_scipost_compute(muse_processing *aProcessing,
     bigpixtable = pixtables[0];
     /* if there is only one pixel table, apply the offset for that */
     cpl_msg_indent_more();
-    muse_scipost_offsets_scale(bigpixtable, offsets,
-                               "single pixel table for resampling");
+    muse_postproc_offsets_scale(bigpixtable, offsets,
+                                "single pixel table for resampling");
     cpl_msg_indent_less();
     muse_wcs_position_celestial(bigpixtable,
                                 muse_pfits_get_ra(bigpixtable->header),
