@@ -65,8 +65,8 @@ __all__ = ['processzap', 'SVDoutput', 'nancleanfits', 'contsubfits', 'Zap',
 
 # Limits of the segments in Angstroms. Zap now uses by default only one
 # segment, see below for the old values.
-SKYSEG = [0, 10000]
-
+SKYSEG = [0,10000]
+                       
 # These are the old limits from the original zap. Keeping them for reference,
 # and may be useful for further testing.
 # [0, 5400, 5850, 6440, 6750, 7200, 7700, 8265, 8602, 8731, 9275, 10000]
@@ -212,7 +212,7 @@ try:
 
     if varcurvefits is not None:
         zobj.writevarcurve(varcurvefits=varcurvefits, overwrite=overwrite)
-    logger.info('check1')
+    
     zobj.mergefits(outcubefits, overwrite=overwrite)
     logger.info('Zapped! (took %.2f sec.)', time() - t0)
 
@@ -413,7 +413,7 @@ try:
         # identify the spectral range of the dataset
         laxmin = min(self.laxis)
         laxmax = max(self.laxis)
-
+        
         # List of segmentation limits in the optical
         skyseg = np.array(SKYSEG)
         skyseg = skyseg[(skyseg > laxmin) & (skyseg < laxmax)]
@@ -421,7 +421,7 @@ try:
         # segment limit in angstroms
         self.lranges = (np.vstack([np.append(laxmin - 10, skyseg),
                                    np.append(skyseg, laxmax + 10)])).T
-
+        logger.info(self.lranges)
         # segment limit in pixels
         laxis = self.laxis
         lranges = self.lranges
@@ -430,7 +430,7 @@ try:
             paxis = wlaxis[(laxis > lranges[i, 0]) & (laxis <= lranges[i, 1])]
             pranges.append((np.min(paxis), np.max(paxis) + 1))
         self.pranges = np.array(pranges)
-
+	logger.info(self.pranges)
         # eigenspace Subset
         if pca_class is not None:
             logger.info('Using %s', pca_class)
@@ -511,7 +511,7 @@ try:
 
         # stuff the new spectra back into the cube
         self.remold()
-        logger.info('check0')
+        
     def _nanclean(self):
         """
         Detects NaN values in cube and removes them by replacing them with an
@@ -1194,14 +1194,14 @@ class MuseZap(esorexplugin.RecipePlugin):
         for j in range(0,len(frames)):
             if frames[j].tag == 'MASK_FINAL_CUBE':
                 mask_filename = frames[j].filename
-            if frames[j].tag == 'DATACUBE_SKYMASK_FINAL_CUBE':
+            if frames[j].tag == 'DATACUBE_SKY':
                 IsThereSkyCube = 1 
                 muse_sky_cubefits_filename = frames[j].filename                
             if frames[j].tag == 'DATACUBE_OBJECT':
                 IsThereObjectCube = 1
                 muse_object_cubefits_filename = frames[j].filename
                
-                
+        
         outcubefits_filename = 'DATACUBE_CLEANED.fits'          
         if IsThereSkyCube ==1:
           IsThereObjectCube = 0
@@ -1213,12 +1213,12 @@ class MuseZap(esorexplugin.RecipePlugin):
           try:
             if nevals == -1:
                nevals = []
-
+            
             processzap(muse_object_cubefits_filename, outcubefits=outcubefits_filename,
                        clean=clean,zlevel=zlevel,cftype=cftype, cfwidthSVD=cfwidthSVD,
                        cfwidthSP=cfwidthSP,  nevals=nevals,ncpu=NCPU, 
-                       extSVD=extSVD, skycubefits=None,  mask=mask_filename, interactive=False)
-                   
+                       extSVD=extSVD, skycubefits=None, interactive=False)
+                 
           except: 
             self.raise_error(' execution error, check if products already exist')
 
@@ -1240,13 +1240,19 @@ class MuseZap(esorexplugin.RecipePlugin):
         hdu = fits.open(outcubefits_filename,method='update')
         hdu[0].header['HIERARCH ESO PRO CATG'] = 'DATACUBE_CLEANED'
         if IsThereSkyCube ==1:
-            hdu[0].header['HIERARCH ESO SKYCUBE'] = muse_sky_cubefits_filename.split("/")[-1]
-            hdu[0].header['HIERARCH ESO SKYCUBE MASK'] =mask_filename.split("/")[-1]
+	    s1=muse_sky_cubefits_filename.split("/")[-1]
+	    s2=mask_filename.split("/")[-1]
+	    s1=s1[:50]
+	    s2=s2[:50]
+            hdu[0].header['HIERARCH ESO SKYCUBE'] = s1
+            hdu[0].header['HIERARCH ESO SKYCUBE MASK'] = s2
         else:
             hdu[0].header['HIERARCH ESO SKYCUBE'] = 'None'
             hdu[0].header['HIERARCH ESO SKYCUBE MASK'] = 'None'
         if IsThereObjectCube ==1:
-            hdu[0].header['HIERARCH ESO OBJECTCUBE MASK'] = mask_filename.split("/")[-1]
+            s3 = mask_filename.split("/")[-1]
+	    s3=s3[:50]
+            hdu[0].header['HIERARCH ESO OBJECTCUBE MASK'] = s3
         else:
             hdu[0].header['HIERARCH ESO OBJECTCUBE MASK'] = 'None'
           
