@@ -2,7 +2,7 @@
 /* vim:set sw=2 sts=2 et cin: */
 /*
  * This file is part of the MUSE Instrument Pipeline
- * Copyright (C) 2007-2017 European Southern Observatory
+ * Copyright (C) 2007-2018 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -828,9 +828,12 @@ int main(int argc, char **argv)
   cpl_test_eq_string(starname, "GD71");
   cpl_propertylist_erase_regexp(fluxobj->response->header,
                                 "ESO QC STANDARD THRU", 1);
-  cpl_test_eq(cpl_propertylist_get_size(fluxobj->response->header), 5);
+  cpl_test_eq(cpl_propertylist_get_size(fluxobj->response->header), 4);
   float thru[] = { 0.3865, 0.2938, 0.2540, 0.1662, 0.1665 };
   for (i = 0; i < 5; i++) {
+    if (i == 1) {
+      continue; /* skip entry at 6000 Angstrom that's not written any more */
+    }
     char *kw = cpl_sprintf("ESO QC STANDARD THRU%04.0f", (i + 5.) * 1000.);
     cpl_test_abs(cpl_propertylist_get_float(fluxobj->response->header, kw),
                  thru[i], 0.01);
