@@ -898,7 +898,7 @@ int main(int argc, char **argv)
   cpl_test(cpl_propertylist_get_size(header) == 4);
 #if 0
   state = cpl_errorstate_get();
-  fn = "muse_test_geo_smoothed.fits";
+  const char *fn = "muse_test_geo_smoothed.fits";
   cpl_msg_info(__func__, "Saving final table as \"%s\"", fn);
   cpl_table_save(geov->table, header, NULL, fn, CPL_IO_CREATE);
   cpl_test(cpl_errorstate_is_equal(state));
@@ -920,6 +920,8 @@ int main(int argc, char **argv)
   cpl_test(rc == CPL_ERROR_NULL_INPUT && !cpl_errorstate_is_equal(state));
   cpl_errorstate_set(state);
   muse_geo_table_delete(geov);
+  /* another duplicate for muse_geo_qc_global() testing below */
+  muse_geo_table *geov3 = muse_geo_table_duplicate(geovkeep);
   /* test wrong columns */
   const char *cols[] = { MUSE_GEOTABLE_FIELD, MUSE_GEOTABLE_CCD, MUSE_GEOTABLE_SKY,
                          MUSE_GEOTABLE_X, MUSE_GEOTABLE_X"err",
@@ -958,5 +960,54 @@ int main(int argc, char **argv)
   } /* for cols (relevant table columns */
   muse_geo_table_delete(geovkeep);
 
+  /* test muse_geo_qc_global() */
+  header = cpl_propertylist_new();
+#if 0
+  cpl_table_save(geov3->table, header, NULL, "muse_test_geov3.fits",
+                 CPL_IO_CREATE);
+#endif
+  state = cpl_errorstate_get();
+  rc = muse_geo_qc_global(geov3, header);
+  cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(state));
+  /* should have created 4 entries, 2 gaps and  */
+#if 0
+  cpl_propertylist_save(header, "bla1.fits", CPL_IO_CREATE);
+  system("dfits bla1.fits");
+  remove("bla1.fits");
+#endif
+  cpl_test_eq(cpl_propertylist_get_size(header), 5);
+  cpl_test_abs(cpl_propertylist_get_double(header, QC_GEO_GAPS_MEAN),
+               0., FLT_EPSILON); /* close to zero for this test dataset */
+  /* failures */
+  state = cpl_errorstate_get();
+  rc = muse_geo_qc_global(NULL, header);
+  cpl_test(rc == CPL_ERROR_NULL_INPUT && !cpl_errorstate_is_equal(state));
+  cpl_errorstate_set(state);
+  cpl_propertylist_delete(header);
+  state = cpl_errorstate_get();
+  rc = muse_geo_qc_global(geov3, NULL);
+  cpl_test(rc == CPL_ERROR_NULL_INPUT && !cpl_errorstate_is_equal(state));
+  cpl_errorstate_set(state);
+  /* partial failure: one missing central slice (IFU 22 SliceSky 17) */
+  header = cpl_propertylist_new();
+  state = cpl_errorstate_get();
+  cpl_table_unselect_all(geov3->table);
+  cpl_table_or_selected_int(geov3->table, MUSE_GEOTABLE_FIELD, CPL_EQUAL_TO, 22);
+  cpl_table_and_selected_int(geov3->table, MUSE_GEOTABLE_SKY, CPL_EQUAL_TO, 17);
+  cpl_table_erase_selected(geov3->table);
+  rc = muse_geo_qc_global(geov3, header);
+  cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(state));
+#if 0
+  cpl_propertylist_save(header, "bla2.fits", CPL_IO_CREATE);
+  system("dfits bla2.fits");
+  remove("bla2.fits");
+#endif
+  /* should have created one entry less (IFU22 GAP MEAN missing, too) */
+  cpl_test_eq(cpl_propertylist_get_size(header), 4);
+  cpl_test_abs(cpl_propertylist_get_double(header, QC_GEO_GAPS_MEAN),
+               0., FLT_EPSILON); /* close to zero for this test dataset */
+  cpl_propertylist_delete(header);
+  muse_geo_table_delete(geov3);
+
   return cpl_test_end(0);
 }
