@@ -2,7 +2,7 @@
 /* vim:set sw=2 sts=2 et cin: */
 /*
  * This file is part of the MUSE Instrument Pipeline
- * Copyright (C) 2007-2016 European Southern Observatory
+ * Copyright (C) 2007-2017 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ muse_test_resampling_cube(muse_pixtable *aPtPix)
 
   /* duplicate the pixel table, project to sky, to also get resampling with WCS */
   muse_pixtable *ptdeg = muse_pixtable_duplicate(aPtPix);
-  cpl_propertylist *wcs = muse_wcs_create_default();
+  cpl_propertylist *wcs = muse_wcs_create_default(NULL);
   cpl_test(muse_wcs_project_tan(ptdeg, wcs) == CPL_ERROR_NONE);
   cpl_propertylist_delete(wcs);
   cpl_test(muse_wcs_position_celestial(ptdeg, muse_pfits_get_ra(ptdeg->header),
