@@ -791,7 +791,7 @@ int main(int argc, char **argv)
    * create and delete a header with a default WCS *
    *************************************************/
   state = cpl_errorstate_get();
-  cpl_propertylist *pwcs = muse_wcs_create_default();
+  cpl_propertylist *pwcs = muse_wcs_create_default(NULL);
   cpl_test(cpl_errorstate_is_equal(state));
   cpl_test(!strncmp("RA---TAN", muse_pfits_get_ctype(pwcs, 1), 9) &&
            !strncmp("DEC--TAN", muse_pfits_get_ctype(pwcs, 2), 9));
@@ -799,10 +799,53 @@ int main(int argc, char **argv)
   muse_wcs *wcs = muse_wcs_new(pwcs);
   cpl_test(cpl_errorstate_is_equal(state));
   cpl_test(wcs->cd11 < 0. && wcs->cd22 > 0. && wcs->cddet != 0.);
+  cpl_test_rel(wcs->cd11, -kMuseSpaxelSizeX_WFM/3600., DBL_EPSILON);
+  cpl_test_rel(wcs->cd22, kMuseSpaxelSizeY_WFM/3600., DBL_EPSILON);
   cpl_test(wcs->cd12 == 0. && wcs->cd21 == 0.);
   cpl_free(wcs);
   cpl_propertylist_delete(pwcs);
 
+  /* same but giving it a header without interesting entries */
+  cpl_propertylist *header = cpl_propertylist_new();
+  cpl_propertylist_append_string(header, "ESO SOMETHING", "not WFM");
+  state = cpl_errorstate_get();
+  pwcs = muse_wcs_create_default(header);
+  cpl_test(cpl_errorstate_is_equal(state));
+  cpl_propertylist_delete(pwcs);
+
+  /* now with with a header with an instrument mode entry */
+  cpl_propertylist_append_string(header, "ESO INS MODE", "WFM-AO-N");
+  pwcs = muse_wcs_create_default(header);
+  cpl_test(cpl_errorstate_is_equal(state));
+  cpl_test(!strncmp("RA---TAN", muse_pfits_get_ctype(pwcs, 1), 9) &&
+           !strncmp("DEC--TAN", muse_pfits_get_ctype(pwcs, 2), 9));
+  state = cpl_errorstate_get();
+  wcs = muse_wcs_new(pwcs);
+  cpl_test(cpl_errorstate_is_equal(state));
+  cpl_test(wcs->cd11 < 0. && wcs->cd22 > 0. && wcs->cddet != 0.);
+  cpl_test_rel(wcs->cd11, -kMuseSpaxelSizeX_WFM/3600., DBL_EPSILON);
+  cpl_test_rel(wcs->cd22, kMuseSpaxelSizeY_WFM/3600., DBL_EPSILON);
+  cpl_test(wcs->cd12 == 0. && wcs->cd21 == 0.);
+  cpl_free(wcs);
+  cpl_propertylist_delete(pwcs);
+
+  /* finally with with a header with an NFM instrument mode entry */
+  cpl_propertylist_update_string(header, "ESO INS MODE", "NFM-AO-N");
+  pwcs = muse_wcs_create_default(header);
+  cpl_test(cpl_errorstate_is_equal(state));
+  cpl_test(!strncmp("RA---TAN", muse_pfits_get_ctype(pwcs, 1), 9) &&
+           !strncmp("DEC--TAN", muse_pfits_get_ctype(pwcs, 2), 9));
+  state = cpl_errorstate_get();
+  wcs = muse_wcs_new(pwcs);
+  cpl_test(cpl_errorstate_is_equal(state));
+  cpl_test(wcs->cd11 < 0. && wcs->cd22 > 0. && wcs->cddet != 0.);
+  cpl_test_rel(wcs->cd11, -kMuseSpaxelSizeX_NFM/3600., DBL_EPSILON);
+  cpl_test_rel(wcs->cd22, kMuseSpaxelSizeY_NFM/3600., DBL_EPSILON);
+  cpl_test(wcs->cd12 == 0. && wcs->cd21 == 0.);
+  cpl_free(wcs);
+  cpl_propertylist_delete(pwcs);
+  cpl_propertylist_delete(header);
+
   /****************************************
    * test transformations of pixel tables *
    ****************************************/
